import os
from PyPDF2 import PdfReader, PdfWriter

def check_and_correct_pdf(input_file):
    reader = PdfReader(input_file)
    writer = PdfWriter()

    if len(reader.pages) < 3:
        print(f"The PDF {input_file} has fewer than 3 pages. No changes made.")
        return

    # Get the sizes of the first three pages
    sizes = [page.mediabox for page in reader.pages[:3]]

    # Check if the first page size is different from the second and third
    if sizes[0] != sizes[1] or sizes[0] != sizes[2]:
        print(f"First page size is different in {input_file}. Removing it...")
        # Add all pages except the first one to the new PDF
        for page in reader.pages[1:]:
            writer.add_page(page)
        
        # Write the new PDF, overwriting the original fil
        with open(input_file, "wb") as f:
            writer.write(f)
        print(f"Updated PDF: {input_file}")
    else:
        print(f"All page sizes are the same in {input_file}. No changes made.")

def get_adjacent_folders():
    script_directory = os.path.dirname(os.path.abspath(__file__))
    return [f for f in os.listdir(script_directory) 
            if os.path.isdir(os.path.join(script_directory, f)) and f != '__pycache__']

def process_pdfs_in_folders():
    script_directory = os.path.dirname(os.path.abspath(__file__))
    folders = get_adjacent_folders()
    
    if not folders:
        print("No adjacent folders found.")
        return
    
    print(f"Found {len(folders)} adjacent folders: {', '.join(folders)}")
    
    for folder in folders:
        folder_path = os.path.join(script_directory, folder)
        print(f"\nProcessing folder: {folder}")
        pdf_files = [f for f in os.listdir(folder_path) if f.lower().endswith('.pdf')]
        
        if not pdf_files:
            print(f"No PDF files found in {folder}")
            continue
        
        print(f"Found {len(pdf_files)} PDF files. Processing...")
        
        for pdf_file in pdf_files:
            pdf_path = os.path.join(folder_path, pdf_file)
            print(f"\nProcessing: {pdf_path}")
            check_and_correct_pdf(pdf_path)
    
    print("\nAll folders have been processed.")

# Run the script
if __name__ == "__main__":
    process_pdfs_in_folders()